@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 __license__ = 'GPL 3'
 __copyright__ = '2009, John Schember <john@nachtimwald.com>'
@@ -9,7 +10,6 @@ Transform OEB content into FB2 markup
 '''
 
 import re, textwrap, uuid
-from base64 import b64encode
 from datetime import datetime
 
 from lxml import etree
@@ -19,6 +19,8 @@ from calibre.constants import __appname__, __version__
 from calibre.utils.localization import lang_as_iso639_1
 from calibre.utils.img import save_cover_data_to
 from calibre.ebooks.oeb.base import urlnormalize
+from polyglot.builtins import unicode_type, string_or_bytes
+from polyglot.binary import as_base64_unicode
 
 
 class FB2MLizer(object):
@@ -61,12 +63,12 @@ class FB2MLizer(object):
         output.append(self.get_text())
         output.append(self.fb2mlize_images())
         output.append(self.fb2_footer())
-        output = self.clean_text(u''.join(output))
+        output = self.clean_text(''.join(output))
 
         if self.opts.pretty_print:
-            return u'<?xml version="1.0" encoding="UTF-8"?>\n%s' % etree.tostring(etree.fromstring(output), encoding=unicode, pretty_print=True)
+            return '<?xml version="1.0" encoding="UTF-8"?>\n%s' % etree.tostring(etree.fromstring(output), encoding='unicode', pretty_print=True)
         else:
-            return u'<?xml version="1.0" encoding="UTF-8"?>' + output
+            return '<?xml version="1.0" encoding="UTF-8"?>' + output
 
     def clean_text(self, text):
         # Condense empty paragraphs into a line break.
@@ -115,11 +117,11 @@ class FB2MLizer(object):
         metadata['cover'] = self.get_cover()
         metadata['genre'] = self.opts.fb2_genre
 
-        metadata['author'] = u''
+        metadata['author'] = ''
         for auth in self.oeb_book.metadata.creator:
-            author_first = u''
-            author_middle = u''
-            author_last = u''
+            author_first = ''
+            author_middle = ''
+            author_last = ''
             author_parts = auth.value.split(' ')
             if len(author_parts) == 1:
                 author_last = author_parts[0]
@@ -137,30 +139,30 @@ class FB2MLizer(object):
             metadata['author'] += '<last-name>%s</last-name>' % prepare_string_for_xml(author_last)
             metadata['author'] += '</author>'
         if not metadata['author']:
-            metadata['author'] = u'<author><first-name></first-name><last-name></last-name></author>'
+            metadata['author'] = '<author><first-name></first-name><last-name></last-name></author>'
 
-        metadata['keywords'] = u''
-        tags = list(map(unicode, self.oeb_book.metadata.subject))
+        metadata['keywords'] = ''
+        tags = list(map(unicode_type, self.oeb_book.metadata.subject))
         if tags:
             tags = ', '.join(prepare_string_for_xml(x) for x in tags)
             metadata['keywords'] = '<keywords>%s</keywords>'%tags
 
-        metadata['sequence'] = u''
+        metadata['sequence'] = ''
         if self.oeb_book.metadata.series:
             index = '1'
             if self.oeb_book.metadata.series_index:
                 index = self.oeb_book.metadata.series_index[0]
-            metadata['sequence'] = u'<sequence name="%s" number="%s" />' % (prepare_string_for_xml(u'%s' % self.oeb_book.metadata.series[0]), index)
+            metadata['sequence'] = '<sequence name="%s" number="%s" />' % (prepare_string_for_xml('%s' % self.oeb_book.metadata.series[0]), index)
 
-        year = publisher = isbn = u''
+        year = publisher = isbn = ''
         identifiers = self.oeb_book.metadata['identifier']
         for x in identifiers:
-            if x.get(OPF('scheme'), None).lower() == 'uuid' or unicode(x).startswith('urn:uuid:'):
-                metadata['id'] = unicode(x).split(':')[-1]
+            if x.get(OPF('scheme'), None).lower() == 'uuid' or unicode_type(x).startswith('urn:uuid:'):
+                metadata['id'] = unicode_type(x).split(':')[-1]
                 break
         if metadata['id'] is None:
             self.log.warn('No UUID identifier found')
-            metadata['id'] = str(uuid.uuid4())
+            metadata['id'] = unicode_type(uuid.uuid4())
 
         try:
             date = self.oeb_book.metadata['date'][0]
@@ -193,7 +195,7 @@ class FB2MLizer(object):
             from calibre.utils.html2text import html2text
             metadata['comments'] = '<annotation>{}</annotation>'.format(prepare_string_for_xml(html2text(comments.value.strip())))
 
-        return textwrap.dedent(u'''
+        return textwrap.dedent('''
             <FictionBook xmlns="http://www.gribuser.ru/xml/fictionbook/2.0" xmlns:xlink="http://www.w3.org/1999/xlink">
                 <description>
                     <title-info>
@@ -221,7 +223,7 @@ class FB2MLizer(object):
                 </description>\n''') % metadata
 
     def fb2_footer(self):
-        return u'\n</FictionBook>'
+        return '\n</FictionBook>'
 
     def get_cover(self):
         from calibre.ebooks.oeb.base import OEB_RASTER_IMAGES
@@ -229,8 +231,8 @@ class FB2MLizer(object):
         cover_href = None
 
         # Get the raster cover if it's available.
-        if self.oeb_book.metadata.cover and unicode(self.oeb_book.metadata.cover[0]) in self.oeb_book.manifest.ids:
-            id = unicode(self.oeb_book.metadata.cover[0])
+        if self.oeb_book.metadata.cover and unicode_type(self.oeb_book.metadata.cover[0]) in self.oeb_book.manifest.ids:
+            id = unicode_type(self.oeb_book.metadata.cover[0])
             cover_item = self.oeb_book.manifest.ids[id]
             if cover_item.media_type in OEB_RASTER_IMAGES:
                 cover_href = cover_item.href
@@ -254,9 +256,9 @@ class FB2MLizer(object):
             if cover_href in self.oeb_book.manifest.hrefs.keys():
                 if cover_href not in self.image_hrefs.keys():
                     self.image_hrefs[cover_href] = '_%s.jpg' % len(self.image_hrefs.keys())
-            return u'<coverpage><image xlink:href="#%s" /></coverpage>' % self.image_hrefs[cover_href]
+            return '<coverpage><image xlink:href="#%s" /></coverpage>' % self.image_hrefs[cover_href]
 
-        return u''
+        return ''
 
     def get_text(self):
         from calibre.ebooks.oeb.base import XHTML
@@ -305,11 +307,13 @@ class FB2MLizer(object):
                 continue
             if item.media_type in OEB_RASTER_IMAGES:
                 try:
-                    if item.media_type != 'image/jpeg':
+                    if item.media_type not in ('image/jpeg', 'image/png'):
                         imdata = save_cover_data_to(item.data, compression_quality=70)
-                        raw_data = b64encode(imdata)
+                        raw_data = as_base64_unicode(imdata)
+                        content_type = 'image/jpeg'
                     else:
-                        raw_data = b64encode(item.data)
+                        raw_data = as_base64_unicode(item.data)
+                        content_type = item.media_type
                     # Don't put the encoded image on a single line.
                     data = ''
                     col = 1
@@ -319,7 +323,7 @@ class FB2MLizer(object):
                             col = 1
                         col += 1
                         data += char
-                    images.append('<binary id="%s" content-type="image/jpeg">%s\n</binary>' % (self.image_hrefs[item.href], data))
+                    images.append('<binary id="%s" content-type="%s">%s\n</binary>' % (self.image_hrefs[item.href], content_type, data))
                 except Exception as e:
                     self.log.error('Error: Could not include file %s because '
                         '%s.' % (item.href, e))
@@ -395,9 +399,9 @@ class FB2MLizer(object):
         elem = elem_tree
 
         # Ensure what we are converting is not a string and that the fist tag is part of the XHTML namespace.
-        if not isinstance(elem_tree.tag, basestring) or namespace(elem_tree.tag) != XHTML_NS:
+        if not isinstance(elem_tree.tag, string_or_bytes) or namespace(elem_tree.tag) != XHTML_NS:
             p = elem.getparent()
-            if p is not None and isinstance(p.tag, basestring) and namespace(p.tag) == XHTML_NS \
+            if p is not None and isinstance(p.tag, string_or_bytes) and namespace(p.tag) == XHTML_NS \
                     and elem.tail:
                 return [elem.tail]
             return []
